@@ -3,7 +3,7 @@ use 5.008001;
 use strict;
 use warnings;
 
-our $VERSION = "0.02";
+our $VERSION = "0.03";
 
 my @members = qw(SU-METAL YUIMETAL MOAMETAL);
 
@@ -36,7 +36,7 @@ sub facebook {
 
 sub instagram {
     my ($self) = @_;
-    return 'https://www.instagram.com/babymetal_jpn/';
+    return 'https://www.instagram.com/babymetal_official/';
 }
 
 sub twitter {
